Learn R Programming

glmmsr (version 0.1.0)

find_modfr_glmm: Parse a formula (and possibly subformulas)

Description

Parse a formula (and possibly subformulas)

Usage

find_modfr_glmm(formula, subformula = NULL, data = NULL,
  family = gaussian, weights = NULL, offset = NULL)

Arguments

formula
a two-sided linear formula object describing both the fixed-effects and fixed-effects part of the model, with the response on the left of a ~ operator and the terms, separated by + operators, on the right. Random-eff
subformula
a subformula, describing how a substituted variable depends on covariates, or a list of subformulas, if there is more than one Sub() term in formula.
data
an optional data frame, list or environment containing the variables named in formula, and in any of the subformulas.
family
a GLM family, see glm and family.
weights
an optional vector of prior weights to be used in the fitting process. Should be NULL or a numeric vector.
offset
this can be used to specify an a priori known component to be included in the linear predictor during fitting. This should be NULL or a numeric vector of length equal to the number of cases. One or more