lme4, the likelihood may
be approximated by the sequential reduction approximation
or an importance sampling approximation. These methods
provide an accurate approximation to the likelihood in some situations
where it is not possible to use adaptive Gaussian quadrature.The main function of the glmmsr package is glmm, which is
used to fit the GLMM. Its interface allows a larger class of models than
those allowed by lme4, including
structured pairwise comparison models.