Arguments
formula
a two-sided linear formula object describing both the
fixed-effects and fixed-effects part of the model, with the response
on the left of a ~ operator and the terms, separated by
+ operators, on the right. Random-eff
subformula
a subformula, describing how a substituted variable
depends on covariates, or a list of subformulas, if there is more
than one Sub() term in formula.
data
an optional data frame, list or environment containing the
variables named in formula, and in any of the subformulas.
weights
an optional vector of prior weights to be used
in the fitting process. Should be NULL or a numeric
vector.
offset
this can be used to specify an a priori known
component to be included in the linear predictor during
fitting. This should be NULL or a numeric vector of length
equal to the number of cases. One or more